####################################################
Agilent 33521A Function/Arbitrary Waveform Generator
####################################################

.. autoclass:: pymeasure.instruments.agilent.Agilent33521A
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.agilent.agilent33500.Agilent33500Channel
    :members:
    :show-inheritance:
